# eric7.Globals.__init__

Module defining common data to be used by all modules.

### Global Attributes

configDir
recentNameBreakpointConditions
recentNameBreakpointFiles
recentNameFiles
recentNameHexFiles
recentNameHosts
recentNameMultiProject
recentNamePdfFiles
recentNameProject
recentNameTestDiscoverHistory
recentNameTestEnvironment
recentNameTestFileHistory
recentNameTestFramework
recentNameTestNameHistory
settingsNameGlobal
settingsNameOrganization
settingsNameRecent

### Classes

None

### Functions

dataString | Module function to generate a formatted size string.
getConfigDir | Module function to get the name of the directory storing the config data.
getInstallInfoFilePath | Public method to get the path name of the install info file.
getWebBrowserSupport | Module function to determine the supported web browser variant.
setConfigDir | Module function to set the name of the directory storing the config data.
strGroup | Module function to group a string into sub-strings separated by a separator.
strToQByteArray | Module function to convert a Python string into a QByteArray.
toBool | Module function to convert a value to bool.
toByteArray | Module function to convert a value to a byte array.
toDict | Module function to convert a value to a dictionary.
toList | Module function to convert a value to a list.
versionToTuple | Module function to convert a version string into a tuple.

## dataString

dataString(size)

Module function to generate a formatted size string.

size (int)
  size to be formatted

Return:
  formatted data string

Return Type:
  str

Up

## getConfigDir

getConfigDir()

Module function to get the name of the directory storing the config data.

Return:
  directory name of the config dir

Return Type:
  str

Up

## getInstallInfoFilePath

getInstallInfoFilePath()

Public method to get the path name of the install info file.

Return:
  file path of the install info file

Return Type:
  str

Up

## getWebBrowserSupport

getWebBrowserSupport()

Module function to determine the supported web browser variant.

Return:
  string indicating the supported web browser variant ("QtWebEngine", or "None")

Return Type:
  str

Up

## setConfigDir

setConfigDir(d)

Module function to set the name of the directory storing the config data.

d (str)
  name of an existing directory

Up

## strGroup

strGroup(txt, sep, groupLen=4)

Module function to group a string into sub-strings separated by a separator.

txt (str)
  text to be grouped
sep (str)
  separator string
groupLen (int)
  length of each group

Return:
  result string

Return Type:
  str

Up

## strToQByteArray

strToQByteArray(txt)

Module function to convert a Python string into a QByteArray.

txt (str, bytes, bytearray)
  Python string to be converted

Return:
  converted QByteArray

Return Type:
  QByteArray

Up

## toBool

toBool(value)

Module function to convert a value to bool.

value (str)
  value to be converted

Return:
  converted data

Return Type:
  bool

Up

## toByteArray

toByteArray(value)

Module function to convert a value to a byte array.

value (QByteArray or None)
  value to be converted

Return:
  converted data

Return Type:
  QByteArray

Up

## toDict

toDict(value)

Module function to convert a value to a dictionary.

value (dict or None)
  value to be converted

Return:
  converted data

Return Type:
  dict

Up

## toList

toList(value)

Module function to convert a value to a list.

value (None, list or Any)
  value to be converted

Return:
  converted data

Return Type:
  list

Up

## versionToTuple

versionToTuple(version, length=3)

Module function to convert a version string into a tuple.

Note: A version string consists of non-negative decimals separated by "." optionally followed by a suffix. Suffix is everything after the last decimal.

version (str)
  version string
length (int)
  desired length of the version tuple (ignored)

Return:
  version named tuple containing the version parts

Return Type:
  semver.VersionInfo

Up